unit rxWebNewHTMLFileUnit;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, Forms, Controls, Graphics, Dialogs, ButtonPanel,
  StdCtrls, ComCtrls;

type

  { TrxWebNewHTMLFileForm }

  TrxWebNewHTMLFileForm = class(TForm)
    ButtonPanel1: TButtonPanel;
    cbCharset: TComboBox;
    cbShema: TComboBox;
    edtAutor: TEdit;
    edtCopyr: TEdit;
    edtCSS: TComboBox;
    edtJS: TComboBox;
    edtTitle: TEdit;
    Label1: TLabel;
    Label2: TLabel;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    PageControl1: TPageControl;
    TabSheet1: TTabSheet;
    TabSheet2: TTabSheet;
    procedure FormClose(Sender: TObject; var CloseAction: TCloseAction);
    procedure FormCreate(Sender: TObject);
  private
    procedure FillLinks;
    procedure SaveHtmlProps;
    procedure LoadHtmlProps;
  public
    function HtmlText:string;
  end; 

var
  rxWebNewHTMLFileForm: TrxWebNewHTMLFileForm;

const
  HTML_Autor     = 'HTML_Autor';
  HTML_Copyright = 'HTML_Copyright';

implementation
uses rxWebStrConsts, SrcEditorIntf, ProjectIntf, LazIDEIntf;

{$R *.lfm}
const
  HTMLHeaders : array [0..7] of string =
    ('<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">'+LineEnding +
     '<HTML>',

     '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">'+LineEnding +
     '<HTML>',

     '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN" "http://www.w3.org/TR/html4/frameset.dtd">'+LineEnding +
     '<HTML>',

     '<?xml version="1.0" encoding="utf-8"?>'+LineEnding+
     '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">'+LineEnding+
     '<html xmlns="http://www.w3.org/1999/xhtml">',

     '<?xml version="1.0" encoding="utf-8"?>'+LineEnding+
     '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">'+LineEnding+
     '<html xmlns="http://www.w3.org/1999/xhtml">',

     '<?xml version="1.0" encoding="utf-8"?>'+LineEnding+
     '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Frameset//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-frameset.dtd">'+LineEnding+
     '<html xmlns="http://www.w3.org/1999/xhtml">',

     '<?xml version="1.0" encoding="utf-8"?>'+LineEnding+
     '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML Basic 1.0//EN" "http://www.w3.org/TR/xhtml-basic/xhtml-basic10.dtd">'+LineEnding+
     '<html xmlns="http://www.w3.org/1999/xhtml">',

     '<?xml version="1.0" encoding="utf-8"?>'+LineEnding+
     '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">'+LineEnding+
     '<html xmlns="http://www.w3.org/1999/xhtml">'
    );

{ TrxWebNewHTMLFileForm }

procedure TrxWebNewHTMLFileForm.FormCreate(Sender: TObject);
begin
  Caption:=SNewHtmlFileProps;
  Label3.Caption:=SHTMLTitle;//
  Label1.Caption:=SHTMLAutor;
  Label2.Caption:=SHTMLCopyright;
  Label4.Caption:=SHTMLCharset;
  Label5.Caption:=SHTMLCssFile;
  //

  LoadHtmlProps;
  edtCSS.Items.Clear;
  edtJS.Items.Clear;
  FillLinks;
end;

procedure TrxWebNewHTMLFileForm.FormClose(Sender: TObject;
  var CloseAction: TCloseAction);
begin
  if ModalResult = mrOk then
    SaveHtmlProps;
end;

procedure TrxWebNewHTMLFileForm.FillLinks;
var
  i:integer;
  S, Ext:string;
begin
  if Assigned(LazarusIDE) and Assigned(LazarusIDE.ActiveProject) then
  begin
    for i:=0 to LazarusIDE.ActiveProject.FileCount - 1 do
    begin
      S:=LazarusIDE.ActiveProject.Files[i].Filename;
      Ext:=UpperCase(ExtractFileExt(S));
      if Ext = '.JS' then
        edtJS.Items.Add(S)
      else
      if Ext = '.CSS' then
        edtCSS.Items.Add(S);
    end;
  end;
end;

procedure TrxWebNewHTMLFileForm.SaveHtmlProps;
begin
  if Assigned(LazarusIDE) and Assigned(LazarusIDE.ActiveProject) then
  begin
    LazarusIDE.ActiveProject.CustomSessionData.Values[HTML_Autor] := edtAutor.Text;
    LazarusIDE.ActiveProject.CustomSessionData.Values[HTML_Copyright] := edtCopyr.Text;
    LazarusIDE.ActiveProject.Modified:=True;
  end;
end;

procedure TrxWebNewHTMLFileForm.LoadHtmlProps;
begin
  if Assigned(LazarusIDE) and Assigned(LazarusIDE.ActiveProject) then
  begin
    edtAutor.Text := LazarusIDE.ActiveProject.CustomSessionData.Values[HTML_Autor];
    edtCopyr.Text := LazarusIDE.ActiveProject.CustomSessionData.Values[HTML_Copyright];
  end;
end;

function TrxWebNewHTMLFileForm.HtmlText: string;
begin
  Result:= HTMLHeaders[cbShema.ItemIndex] + LineEnding+'  <head>'+LineEnding;
  Result:=Result + '    <title>'+rxWebNewHTMLFileForm.edtTitle.Text+'</title>'+LineEnding;
  if rxWebNewHTMLFileForm.edtAutor.Text <> '' then
    Result:=Result + '    <meta name="author" content="'+rxWebNewHTMLFileForm.edtAutor.Text+'" >'+LineEnding;
  if rxWebNewHTMLFileForm.edtCopyr.Text <> '' then
    Result:=Result + '    <meta name="copyright" content="'+rxWebNewHTMLFileForm.edtCopyr.Text+'">'+LineEnding;
  if rxWebNewHTMLFileForm.cbCharset.Text <> '' then
    Result:=Result + '    <meta http-equiv="content-type" content="text/html; charset='+rxWebNewHTMLFileForm.cbCharset.Text+'">'+LineEnding;
  if rxWebNewHTMLFileForm.edtCSS.Text <> '' then
    Result:=Result + '    <link rel="stylesheet" type="text/css" href="'+rxWebNewHTMLFileForm.edtCSS.Text+'" />'+LineEnding;
  Result:=Result + '  </head>'+LineEnding;
  Result:=Result + '  <body>'+LineEnding;
  Result:=Result + '    <h1> '+rxWebNewHTMLFileForm.edtTitle.Text+' </h1>'+LineEnding;
  Result:=Result + '    <!-- '+SEnterYouText+' -->'+LineEnding;
  Result:=Result + '  </body>'+LineEnding+'</html>'+LineEnding;
end;

end.

