unit rxWebToolsUnit;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, ProjectIntf, LCLType;

type

   { THtmlFileDescriptor }

   THtmlFileDescriptor = class(TProjectFileDescriptor)
   public
     constructor Create; override;
     function GetLocalizedName: string; override;
     function GetLocalizedDescription: string; override;
     function GetResourceSource(const ResourceName: string): string; override;
     function CreateSource(const Filename, SourceName,
                           ResourceName: string): string; override;
     procedure UpdateDefaultPascalFileExtension(const DefPasExt: string); override;
   end;

   { TJSFileDescriptor }

   TJSFileDescriptor = class(TProjectFileDescriptor)
   public
     constructor Create; override;
     function GetLocalizedName: string; override;
     function GetLocalizedDescription: string; override;
     function GetResourceSource(const ResourceName: string): string; override;
     function CreateSource(const Filename, SourceName,
                           ResourceName: string): string; override;
     procedure UpdateDefaultPascalFileExtension(const DefPasExt: string); override;
   end;

   { TCSSFileDescriptor }

   TCSSFileDescriptor = class(TProjectFileDescriptor)
   public
     constructor Create; override;
     function GetLocalizedName: string; override;
     function GetLocalizedDescription: string; override;
     function GetResourceSource(const ResourceName: string): string; override;
     function CreateSource(const Filename, SourceName,
                           ResourceName: string): string; override;
     procedure UpdateDefaultPascalFileExtension(const DefPasExt: string); override;
   end;

procedure Register;

procedure ProcHTMLTable(Sender: TObject);
procedure ProcHTMLGenList(Sender: TObject);

procedure ProcHTMLTableRow(Sender: TObject);
procedure ProcHTMLTableData(Sender: TObject);

procedure ProcHTMLTableRowWD(Sender: TObject);
procedure ProcHTMLTableDataWD(Sender: TObject);

procedure ProcHTMLTextHeader1(Sender: TObject);
procedure ProcHTMLTextHeader2(Sender: TObject);
procedure ProcHTMLTextHeader3(Sender: TObject);
procedure ProcHTMLTextHeader4(Sender: TObject);
procedure ProcHTMLTextHeader5(Sender: TObject);
procedure ProcHTMLColor(Sender: TObject);

procedure ProcHTMLHR(Sender: TObject);
procedure ProcHTMLBR(Sender: TObject);
procedure ProcHTMLComment(Sender: TObject);

procedure ProcHTMLForm(Sender: TObject);
procedure ProcHTMLInputTag(Sender: TObject);
procedure ProcHTMLInputSubmitTag(Sender: TObject);
procedure ProcHTMLInputResetTag(Sender: TObject);
procedure ProcHTMLImageTag(Sender: TObject);

procedure ProcOtherInsertFileName(Sender: TObject);

implementation
uses LResources, NewItemIntf, Forms, Controls, IDECommands,
  MenuIntf, SrcEditorIntf, Dialogs,
  //HTML
  rxWebNewHTMLFileUnit, rxWebStrConsts, rxWebNewHtmlTableUnit,
  rxwebNewHTMLListUnit, rxwebNewHtmlTagTRUnit, rxwebNewHTMLFormUnit,
  rxwebNewHTMLInputUnit, rxwebNewHTMLImgUnit,
  //Other
  rxIDEExtEditorInsertFileNameUnit;

var
  CmdHTMLTable : TIDECommand;
  CmdHTMLList : TIDECommand;

  CmdHTMLTableRow : TIDECommand;
  CmdHTMLTableData : TIDECommand;

  CmdHTMLTableRowWD : TIDECommand;
  CmdHTMLTableDataWD : TIDECommand;

  CmdHTMLTextStyleH1 : TIDECommand;
  CmdHTMLTextStyleH2 : TIDECommand;
  CmdHTMLTextStyleH3 : TIDECommand;
  CmdHTMLTextStyleH4 : TIDECommand;
  CmdHTMLTextStyleH5 : TIDECommand;
  CmdHTMLColor : TIDECommand;

  CmdHTMLHR : TIDECommand;
  CmdHTMLBR : TIDECommand;
  CmdHTMLComment : TIDECommand;


  CmdHTMLFrom : TIDECommand;
  CmdHTMLInput : TIDECommand;
  CmdHTMLInputSubmit : TIDECommand;
  CmdHTMLInputReset : TIDECommand;

  CmdHTMLIMG : TIDECommand;

  CmdOtherInsFileName : TIDECommand;

procedure CreateHTMLToolsMenu;
var
  Key: TIDEShortCut;
  Cat: TIDECommandCategory;
  mnuHTMLMain : TIDEMenuSection;
  mnuHTMLSection : TIDEMenuSection;
  mnuHTMLStyles : TIDEMenuSection;
  mnuHTMLOther : TIDEMenuSection;
begin
  Key:=IDEShortCut(VK_UNKNOWN,[],VK_UNKNOWN,[]);

  Cat:=IDECommandList.CreateCategory(nil, 'HTMLEditor', SmiHTMLEditor,
    IDECmdScopeSrcEditOnly);

  CmdHTMLTable := RegisterIDECommand(Cat, 'HTMLTable', SmiHTMLInsertTable, Key, nil, @ProcHTMLTable);
  CmdHTMLList := RegisterIDECommand(Cat, 'HTMLList', SmiHTMLInsertList, Key, nil, @ProcHTMLGenList);

  CmdHTMLTableRow := RegisterIDECommand(Cat, 'HTMLTableRow', SmiHTMLInsertTableRow, Key, nil, @ProcHTMLTableRow);
  CmdHTMLTableData := RegisterIDECommand(Cat, 'HTMLTableData', SmiHTMLInsertTableData, Key, nil, @ProcHTMLTableData);

  CmdHTMLTableRowWD  := RegisterIDECommand(Cat, 'HTMLTableRowWD', SmiHTMLInsertTableRowWD, Key, nil, @ProcHTMLTableRowWD);
  CmdHTMLTableDataWD := RegisterIDECommand(Cat, 'HTMLTableDataWD', SmiHTMLInsertTableDataWD, Key, nil, @ProcHTMLTableDataWD);

  CmdHTMLTextStyleH1 := RegisterIDECommand(Cat, 'HTMLTextStyleH1', SmiHTMLInsertHeader1Level, Key, nil, @ProcHTMLTextHeader1);
  CmdHTMLTextStyleH2 := RegisterIDECommand(Cat, 'HTMLTextStyleH2', SmiHTMLInsertHeader2Level, Key, nil, @ProcHTMLTextHeader2);
  CmdHTMLTextStyleH3 := RegisterIDECommand(Cat, 'HTMLTextStyleH3', SmiHTMLInsertHeader3Level, Key, nil, @ProcHTMLTextHeader3);
  CmdHTMLTextStyleH4 := RegisterIDECommand(Cat, 'HTMLTextStyleH4', SmiHTMLInsertHeader4Level, Key, nil, @ProcHTMLTextHeader4);
  CmdHTMLTextStyleH5 := RegisterIDECommand(Cat, 'HTMLTextStyleH5', SmiHTMLInsertHeader5Level, Key, nil, @ProcHTMLTextHeader5);
  CmdHTMLColor := RegisterIDECommand(Cat, 'HTMLColor', SmiHTMLInsertColor, Key, nil, @ProcHTMLColor);

  CmdHTMLHR := RegisterIDECommand(Cat, 'HTMLHR', SmiHTMLInsertHR, Key, nil, @ProcHTMLHR);
  CmdHTMLBR := RegisterIDECommand(Cat, 'HTMLBR', SmiHTMLInsertBR, Key, nil, @ProcHTMLBR);
  CmdHTMLComment := RegisterIDECommand(Cat, 'HTMLComment', SmiHTMLInsertComment, Key, nil, @ProcHTMLComment);


  CmdHTMLFrom := RegisterIDECommand(Cat, 'HTMLForm', SmiHTMLInsertForm, Key, nil, @ProcHTMLForm);
  CmdHTMLInput:= RegisterIDECommand(Cat, 'HTMLInput', SmiHTMLInsertInput, Key, nil, @ProcHTMLInputTag);
  CmdHTMLInputSubmit := RegisterIDECommand(Cat, 'HTMLInputSubmit', SmiHTMLInsertInputSubmit, Key, nil, @ProcHTMLInputSubmitTag);
  CmdHTMLInputReset := RegisterIDECommand(Cat, 'HTMLInputReset', SmiHTMLInsertInputReset, Key, nil, @ProcHTMLInputResetTag);
  CmdHTMLIMG := RegisterIDECommand(Cat, 'HTMLIMG', SmiHTMLInsertIMG, Key, nil, @ProcHTMLImageTag);

  CmdOtherInsFileName:=RegisterIDECommand(Cat, 'OtherInsFN', SmiOtherInsertFN, Key, nil, @ProcOtherInsertFileName);

  //  mnuHTMLMain := RegisterIDEMenuRoot('HTML');//RegisterIDEMenuSection(itmCustomTools, 'HTMLEditor');
  mnuHTMLMain := RegisterIDEMenuSection(mnuMain, 'HTMLEditor');

  mnuHTMLSection:=RegisterIDESubMenu(mnuHTMLMain, 'HTMLEditor', SmiHTMLEditor, nil, nil);

  mnuHTMLStyles :=RegisterIDESubMenu(mnuHTMLSection, 'HTMLStyle', SmiHTMLStyle, nil, nil);

  RegisterIDEMenuCommand(mnuHTMLSection, 'HTMLTable', SmiHTMLInsertTable, nil, nil,
    CmdHTMLTable, 'quick_table');
  RegisterIDEMenuCommand(mnuHTMLSection, 'HTMLTableRow', SmiHTMLInsertTableRow, nil, nil,
    CmdHTMLTableRow, 'tag_tr');
  RegisterIDEMenuCommand(mnuHTMLSection, 'HTMLTableData', SmiHTMLInsertTableData, nil, nil,
    CmdHTMLTableData, 'tag_td');
  RegisterIDEMenuCommand(mnuHTMLSection, 'HTMLTableRowWD', SmiHTMLInsertTableRowWD, nil, nil,
    CmdHTMLTableRowWD, 'tag_table_row');
  RegisterIDEMenuCommand(mnuHTMLSection, 'HTMLTableDataWD', SmiHTMLInsertTableDataWD, nil, nil,
    CmdHTMLTableDataWD, 'tag_table_data');


  RegisterIDEMenuCommand(mnuHTMLSection, 'HTMLList', SmiHTMLInsertList, nil, nil,
    CmdHTMLList, 'HTMLList');

  RegisterIDEMenuCommand(mnuHTMLStyles, 'HTMLTextHeader1', SmiHTMLInsertHeader1Level, nil, nil,
    CmdHTMLTextStyleH1, 'tag_h1');
  RegisterIDEMenuCommand(mnuHTMLStyles, 'HTMLTextHeader2', SmiHTMLInsertHeader2Level, nil, nil,
    CmdHTMLTextStyleH2, 'tag_h2');
  RegisterIDEMenuCommand(mnuHTMLStyles, 'HTMLTextHeader3', SmiHTMLInsertHeader3Level, nil, nil,
    CmdHTMLTextStyleH3, 'tag_h3');
  RegisterIDEMenuCommand(mnuHTMLStyles, 'HTMLTextHeader4', SmiHTMLInsertHeader4Level, nil, nil,
    CmdHTMLTextStyleH4, 'tag_h4');
  RegisterIDEMenuCommand(mnuHTMLStyles, 'HTMLTextHeader5', SmiHTMLInsertHeader5Level, nil, nil,
    CmdHTMLTextStyleH5, 'tag_h5');

//  mnuHTMLStiles :=RegisterIDESubMenu(mnuHTMLSection, 'HTMLEditor', SmiHTMLEditor, nil, nil);
  RegisterIDEMenuCommand(mnuHTMLStyles, 'HTMLColor', SmiHTMLInsertColor, nil, nil,
    CmdHTMLColor, 'color-picker');

  RegisterIDEMenuCommand(mnuHTMLSection, 'HTMLHR', SmiHTMLInsertHR, nil, nil,
    CmdHTMLHR, 'tag_hr');
  RegisterIDEMenuCommand(mnuHTMLSection, 'HTMLBR', SmiHTMLInsertBR, nil, nil,
    CmdHTMLBR, 'tag_br');
  RegisterIDEMenuCommand(mnuHTMLSection, 'HTMLComment', SmiHTMLInsertComment, nil, nil,
    CmdHTMLComment, 'tag_comm');

  RegisterIDEMenuCommand(mnuHTMLSection, 'HTMLForm', SmiHTMLInsertForm, nil, nil,
    CmdHTMLFrom, 'HTMLForm');
  RegisterIDEMenuCommand(mnuHTMLSection, 'HTMLInput', SmiHTMLInsertInput, nil, nil,
    CmdHTMLInput, 'lineedit');
  RegisterIDEMenuCommand(mnuHTMLSection, 'HTMLInputSubmit', SmiHTMLInsertInputSubmit, nil, nil,
    CmdHTMLInputSubmit, 'submit');
  RegisterIDEMenuCommand(mnuHTMLSection, 'HTMLInputReset', SmiHTMLInsertInputReset, nil, nil,
    CmdHTMLInputReset, 'reset');

  RegisterIDEMenuCommand(mnuHTMLSection, 'HTMLIMG', SmiHTMLInsertIMG, nil, nil,
    CmdHTMLIMG, 'tag_image');

  mnuHTMLOther :=RegisterIDESubMenu(mnuHTMLSection, 'HTMLOther', SmiHTMLOther, nil, nil);
  RegisterIDEMenuCommand(mnuHTMLOther, 'OtherInsFN', SmiOtherInsertFN, nil, nil,
    CmdOtherInsFileName, '');

end;

procedure Register;
begin
  RegisterNewItemCategory(TNewIDEItemCategory.Create(SHtmlDesign));
  RegisterProjectFileDescriptor(THtmlFileDescriptor.Create, SHtmlDesign);
  RegisterProjectFileDescriptor(TJSFileDescriptor.Create, SHtmlDesign);
  RegisterProjectFileDescriptor(TCSSFileDescriptor.Create, SHtmlDesign);

  CreateHTMLToolsMenu;
end;

procedure ProcHTMLTable(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
  begin
    rxWebNewHtmlTableForm:=TrxWebNewHtmlTableForm.Create(Application);
    if rxWebNewHtmlTableForm.ShowModal = mrOk then
       SourceEditorManagerIntf.ActiveEditor.Selection:=rxWebNewHtmlTableForm.HtmlText;
    rxWebNewHtmlTableForm.Free;
  end
end;

procedure ProcHTMLGenList(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
  begin
    rxwebNewHTMLListForm:=TrxwebNewHTMLListForm.Create(Application);
    if rxwebNewHTMLListForm.ShowModal = mrOk then
       SourceEditorManagerIntf.ActiveEditor.Selection:=rxwebNewHTMLListForm.HtmlText;
    rxwebNewHTMLListForm.Free;
  end
end;

procedure ProcHTMLTableRow(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
    SourceEditorManagerIntf.ActiveEditor.Selection:='<tr> </tr>';
end;

procedure ProcHTMLTableData(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
    SourceEditorManagerIntf.ActiveEditor.Selection:='<td> </td>';
end;

procedure ProcHTMLTableRowWD(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
  begin
    rxwebNewHtmlTagTRForm:=TrxwebNewHtmlTagTRForm.Create(Application);
    if rxwebNewHtmlTagTRForm.ShowModal = mrOk then
       SourceEditorManagerIntf.ActiveEditor.Selection:=rxwebNewHtmlTagTRForm.HtmlText;
    rxwebNewHtmlTagTRForm.Free;
  end
end;

procedure ProcHTMLTableDataWD(Sender: TObject);
begin

end;

procedure ProcHTMLTextHeader1(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
    SourceEditorManagerIntf.ActiveEditor.Selection:='<H1> </H1>';
end;

procedure ProcHTMLTextHeader2(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
    SourceEditorManagerIntf.ActiveEditor.Selection:='<H2> </H2>';
end;

procedure ProcHTMLTextHeader3(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
    SourceEditorManagerIntf.ActiveEditor.Selection:='<H3> </H3>';

end;

procedure ProcHTMLTextHeader4(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
    SourceEditorManagerIntf.ActiveEditor.Selection:='<H4> </H4>';

end;

procedure ProcHTMLTextHeader5(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
    SourceEditorManagerIntf.ActiveEditor.Selection:='<H5> </H5>';
end;

procedure ProcHTMLColor(Sender: TObject);
var
  Dlg:TColorDialog;
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
  begin
    Dlg:=TColorDialog.Create(Application);
    try
      if Dlg.Execute then
        SourceEditorManagerIntf.ActiveEditor.Selection:='#'+IntToHex(Dlg.Color, 6);
    finally
      Dlg.Free;
    end;
  end;
end;

procedure ProcHTMLHR(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
    SourceEditorManagerIntf.ActiveEditor.Selection:='<HR>';
end;

procedure ProcHTMLBR(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
    SourceEditorManagerIntf.ActiveEditor.Selection:='<BR>';
end;

procedure ProcHTMLComment(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
    SourceEditorManagerIntf.ActiveEditor.Selection:='<!-- -->';
end;

procedure ProcHTMLForm(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
  begin
    rxwebNewHTMLFormForm:=TrxwebNewHTMLFormForm.Create(Application);
    if rxwebNewHTMLFormForm.ShowModal = mrOk then
       SourceEditorManagerIntf.ActiveEditor.Selection:=rxwebNewHTMLFormForm.HtmlText;
    rxwebNewHTMLFormForm.Free;
  end
end;

procedure ProcHTMLInputTag(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
  begin
    rxwebNewHTMLInputForm:=TrxwebNewHTMLInputForm.Create(Application);
    if rxwebNewHTMLInputForm.ShowModal = mrOk then
       SourceEditorManagerIntf.ActiveEditor.Selection:=rxwebNewHTMLInputForm.HtmlText;
    rxwebNewHTMLInputForm.Free;
  end
end;

procedure ProcHTMLInputSubmitTag(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
  begin
    rxwebNewHTMLInputForm:=TrxwebNewHTMLInputForm.Create(Application);
    rxwebNewHTMLInputForm.cbType.Text:='submit';
    rxwebNewHTMLInputForm.edtValue.Text:=SHTMLTagCaptionSubmit;
    if rxwebNewHTMLInputForm.ShowModal = mrOk then
       SourceEditorManagerIntf.ActiveEditor.Selection:=rxwebNewHTMLInputForm.HtmlText;
    rxwebNewHTMLInputForm.Free;
  end
end;

procedure ProcHTMLInputResetTag(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
  begin
    rxwebNewHTMLInputForm:=TrxwebNewHTMLInputForm.Create(Application);
    rxwebNewHTMLInputForm.cbType.Text:='reset';
    rxwebNewHTMLInputForm.edtValue.Text:=SHTMLTagCaptionReset;

    if rxwebNewHTMLInputForm.ShowModal = mrOk then
       SourceEditorManagerIntf.ActiveEditor.Selection:=rxwebNewHTMLInputForm.HtmlText;
    rxwebNewHTMLInputForm.Free;
  end
end;

procedure ProcHTMLImageTag(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
  begin
    rxwebNewHTMLImgForm:=TrxwebNewHTMLImgForm.Create(Application);
    if rxwebNewHTMLImgForm.ShowModal = mrOk then
      SourceEditorManagerIntf.ActiveEditor.Selection:=rxwebNewHTMLImgForm.HtmlText;
    rxwebNewHTMLImgForm.Free;
  end;
end;

procedure ProcOtherInsertFileName(Sender: TObject);
begin
  if Assigned(SourceEditorManagerIntf) and Assigned(SourceEditorManagerIntf.ActiveEditor) then
  begin
    rxIDEExtEditorInsertFileNameForm:=TrxIDEExtEditorInsertFileNameForm.Create(Application);
    if rxIDEExtEditorInsertFileNameForm.ShowModal = mrOk then
      SourceEditorManagerIntf.ActiveEditor.Selection:=rxIDEExtEditorInsertFileNameForm.SelectedFile;
    rxIDEExtEditorInsertFileNameForm.Free;
  end;
end;

{ THtmlFileDescriptor }

constructor THtmlFileDescriptor.Create;
begin
  inherited Create;
  Name:='Html file';
  DefaultFilename:='index.html';
  DefaultResFileExt:='';
  DefaultFileExt:='.html';
  VisibleInNewDialog:=true;
end;

function THtmlFileDescriptor.GetLocalizedName: string;
begin
  Result:=SHtmlFile;
end;

function THtmlFileDescriptor.GetLocalizedDescription: string;
begin
  Result:=SHtmlFileDesc;
end;

function THtmlFileDescriptor.GetResourceSource(const ResourceName: string
  ): string;
begin
  Result:='';
end;

function THtmlFileDescriptor.CreateSource(const Filename, SourceName,
  ResourceName: string): string;
begin
  Result:='';
  rxWebNewHTMLFileForm:=TrxWebNewHTMLFileForm.Create(Application);
  if rxWebNewHTMLFileForm.ShowModal = mrOk then
  begin
    Result:=rxWebNewHTMLFileForm.HtmlText;
  end;
  rxWebNewHTMLFileForm.Free;
end;

procedure THtmlFileDescriptor.UpdateDefaultPascalFileExtension(
  const DefPasExt: string);
begin
  //inherited UpdateDefaultPascalFileExtension(DefPasExt);
end;

{ TJSFileDescriptor }

constructor TJSFileDescriptor.Create;
begin
  inherited Create;
  Name:='Java script file';
  DefaultFilename:='functions.js';
  DefaultResFileExt:='';
  DefaultFileExt:='.js';
  VisibleInNewDialog:=true;
end;

function TJSFileDescriptor.GetLocalizedName: string;
begin
  Result:=SJSFile;
end;

function TJSFileDescriptor.GetLocalizedDescription: string;
begin
  Result:=SJSFileDesc;
end;

function TJSFileDescriptor.GetResourceSource(const ResourceName: string
  ): string;
begin
  Result:='';
end;

function TJSFileDescriptor.CreateSource(const Filename, SourceName,
  ResourceName: string): string;
begin
  Result:='/* Enter your CSS here... */';
end;

procedure TJSFileDescriptor.UpdateDefaultPascalFileExtension(
  const DefPasExt: string);
begin
  //
end;

{ TCSSFileDescriptor }

constructor TCSSFileDescriptor.Create;
begin
  inherited Create;
  Name:='CSS file';
  DefaultFilename:='styles.css';
  DefaultResFileExt:='';
  DefaultFileExt:='.css';
  VisibleInNewDialog:=true;
end;

function TCSSFileDescriptor.GetLocalizedName: string;
begin
  Result:=SCSSFile;
end;

function TCSSFileDescriptor.GetLocalizedDescription: string;
begin
  Result:=SCSSFileDesc;
end;

function TCSSFileDescriptor.GetResourceSource(const ResourceName: string
  ): string;
begin
  Result:='';
end;

function TCSSFileDescriptor.CreateSource(const Filename, SourceName,
  ResourceName: string): string;
begin
  Result:='/* Enter your funtions here */';
end;

procedure TCSSFileDescriptor.UpdateDefaultPascalFileExtension(
  const DefPasExt: string);
begin
  //
end;

initialization
  {$I rxweb_images.inc}
end.

